package sklep.model;

import jakarta.persistence.*;
import jakarta.validation.constraints.*;
import org.hibernate.annotations.ColumnDefault;

import java.math.BigDecimal;

@Entity
@Table(name = "products")
@NamedQuery(name="Product.findAll", query="SELECT p FROM Product p ORDER BY p.id")
public class Product {
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ColumnDefault("nextval('products_seq'::regclass)")
    @Column(name = "product_id", nullable = false)
    private Integer id;

    @Column(name = "product_name", nullable = false, length = 100)
    @NotBlank
    @Size(min=1, max=20)
    private String productName;

    @Column(name = "price", nullable = false, precision = 10, scale = 2)
    @DecimalMin("0.01")
    @DecimalMax("99999.99") // ceny od 100 tys nie będą akceptowane
    private BigDecimal price;

    @Column(name = "vat", precision = 2, scale = 2)
    @Min(0)
    private BigDecimal vat;

    @Column(name = "description", length = Integer.MAX_VALUE)
    private String description;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getVat() {
        return vat;
    }

    public void setVat(BigDecimal vat) {
        this.vat = vat;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

}